@@ -16,19 +16,23 @@ class ManagerServer(ThreadingTCPServer):
         ThreadingTCPServer.__init__(self, (host, port), RequestHandler)
 
     def get_request(self):
+        # Calls accept inside
         client_sock, client_addr = ThreadingTCPServer.get_request(self)
-        self.clients[client_addr] = ClientStruct(client_sock)
+
+        # Hold a reference to our new client
+        self.clients[client_addr] = Client(client_sock)
         print 'self.clients', pformat(self.clients)
+
         return client_sock, client_addr
 
     def process_request_thread(self, request, client_address):
-        ThreadingTCPServer.process_request_thread(self, request,
-                                                  client_address)
-        self._remove_socket(client_address)
-
-    def _remove_socket(self, client_address):
-        del self.clients[client_address]
-        print 'self.clients', pformat(self.clients)
+        try:
+            ThreadingTCPServer.process_request_thread(
+                self, request, client_address)
+        finally:
+            # Client is no longer connected, remove the reference
+            del self.clients[client_address]
+            print 'self.clients', pformat(self.clients)
 
 
 class RequestHandler(BaseRequestHandler):
@@ -55,10 +59,9 @@ class RequestHandler(BaseRequestHandler):
 
 
 @total_ordering
-class ClientStruct(dict):
+class Client(object):
 
     def __init__(self, socket):
-        super(ClientStruct, self).__init__()
         self.socket = socket
         self.stats = {}
         self.actions = Queue.Queue()
